@@ -29,15 +29,15 @@ class SandBoxAdmin(admin.ModelAdmin):
 
 
 class TransactAdmin(admin.ModelAdmin):
-    fields = ('id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+    fields = ('id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
               'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
               'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     list_display = (
-        'id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
         'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     search_fields = (
-        'id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
         'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     # list_filter = ['platform', 'currency', 'account', 'their_account', 'order_no']
