@@ -91,7 +91,7 @@ class Transact(models.Model):
     create_transact_id = year_timestamp() + zero_code
 
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
-    transact_id = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
+    transact_no = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
     enroll_id = models.BigIntegerField(verbose_name='报名id', db_index=True, null=True, )  # 应为transact号
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default='') # 应为transact号
     transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
@@ -117,7 +117,10 @@ class Transact(models.Model):
     images = models.CharField(verbose_name='多图上传', blank=True, null=True, max_length=1000)
     sand_box = models.ForeignKey(verbose_name='沙盒', to=SandBox, db_column='sand_box_id', related_name='+',
                                  on_delete=models.DO_NOTHING, unique=False, blank=True, null=True, db_index=True)
+    finance_status_code = models.IntegerField(verbose_name='资金状态码', default='')
     is_reverse = models.BooleanField(verbose_name='是否红冲', max_length=255, blank=True, null=True)
+    is_delete = models.BooleanField(verbose_name='是否删除', max_length=255, blank=True, null=True)
+    is_write_off = models.BooleanField(verbose_name='是否核销', max_length=255, blank=True, null=True)
 
     class Meta:
         db_table = 'finance_transact'
@@ -132,3 +135,16 @@ class Transact(models.Model):
     # “反向” 关联
     # 若模型有ForeignKey，外键关联的模型实例将能访问Manager，后者会返回第一个模型的所有实例。默认情况下，该Manager名为FOO_set， FOO即源模型名的小写形式。 Manager返回QuerySets，后者能以 “检索对象” 章节介绍的方式进行筛选和操作。
     # 你可以在定义ForeignKey时设置related_name参数重写这个FOO_set名。例如，若修改Entry模型为blog = ForeignKey(Blog, on_delete=models.CASCADE, related_name='entries')，前文示例代码会看起来像这样:
+
+
+class StatusCode(models.Model):
+    id = models.AutoField(verbose_name='ID', primary_key=True)
+    finance_status_code = models.CharField(verbose_name='资金状态码', max_length=128)
+    description = models.CharField(verbose_name='描述', max_length=128)
+
+    class Meta:
+        db_table = 'finance_status_code'
+        verbose_name_plural = "8. 财务 - 资金状态码表"
+
+    def __str__(self):
+        return f"{self.finance_status_code}"
