@@ -5,13 +5,11 @@ import datetime
 from django.db.models import Q
 from django.db.models import F
 from django.forms import model_to_dict
-from rest_framework.response import Response
-
-from xj_user.models import *
 from xj_user.services.user_platform_service import UserPlatformService
 from ..models import *
 
 from decimal import Decimal
+from ..utils.custom_tool import format_params_handle
 
 
 class FinanceService:
@@ -286,3 +284,4 @@ class FinanceService:
     #     transacts = transacts.order_by('-transact_time')
     #
     #     return {'err': 0, 'msg': 'OK', 'query_set': transacts, }
+
