@@ -38,6 +38,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
     sand_box = serializers.SerializerMethodField()
     transact_time = serializers.SerializerMethodField()
     transact_timestamp = serializers.SerializerMethodField()
+    # finance_status_code = serializers.SerializerMethodField()
 
     # 自定义外键字段
     # platform = serializers.ReadOnlyField(source='platform.platform_name')
@@ -57,7 +58,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
         model = Transact
         fields = [
             'id',
-            'transact_id',
+            'transact_no',
             'transact_time',
             'transact_timestamp',
             'account_id',
@@ -81,6 +82,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
             'sand_box',
             'goods_info',
             'pay_info',
+            'finance_status_code'
         ]
 
     def get_lend(self, obj):
@@ -127,7 +129,7 @@ class FinanceTransactService:
         # if not user_id:
         #     return Response({'err': 4002, 'msg': 'token验证失败', })
 
-        id = params.get('transact_id', None) or params.get('id', None)
+        id = params.get('transact_no', None) or params.get('id', None)
         if not id:
             # return Response({'err': 6001, 'msg': '缺少id', })
             return None, '缺少id'
@@ -145,11 +147,11 @@ class FinanceTransactService:
 
         return serializer.data, None
 
-        # POST方法，如果无transact_id则是新增，否则为修改
+        # POST方法，如果无transact_no则是新增，否则为修改
 
     @staticmethod
-    def finance_transact_detailed(transact_id):
-        transact = Transact.objects.filter(transact_id=transact_id).first()
+    def finance_transact_detailed(transact_no):
+        transact = Transact.objects.filter(transact_no=transact_no).first()
         if not transact:
             return None, "不存在"
         return transact, None
@@ -179,11 +181,17 @@ class FinanceTransactService:
         if not param.get('summary', ''):
             return None, '缺少summary'
         # ========== 三、内容的类型准确性检查 ==========
-        # 判断无transact_id为新建，否则为修改
+        # 判断无transact_no为新建，否则为修改
         is_create = True
-        transact_has_id = Transact.objects.filter(transact_id=param.get('transact_id', ''))
+        item['sand_box'] = None
+        transact_has_id = Transact.objects.filter(transact_no=param.get('transact_no', '')).first()
         if transact_has_id:
+            res_data = model_to_dict(transact_has_id)
+            if not res_data['sand_box']:
+                return None, '非沙盒数据不允许修改'
             is_create = False
+
+
         # 检查是否有该id
         if not is_create and param.get('id', ''):
             has_id = Transact.objects.filter(id=param.get('id', '')).count() > 0
@@ -218,19 +226,19 @@ class FinanceTransactService:
         # 生成发起交易的用户名 todo 要不用金额会不会更安全？怎么处理重复的可能性
         username = item['account'].user_name
         # 生成唯一且不可重复的交易ID，且具有校验作用
-        if is_create and param.get('transact_id', ''):
+        if is_create and param.get('transact_no', ''):
 
-            transact_id = param.get('transact_id', '')
-        elif is_create and not param.get('transact_id', ''):
-            transact_id = FinanceService.make_unicode(username)
+            transact_no = param.get('transact_no', '')
+        elif is_create and not param.get('transact_no', ''):
+            transact_no = FinanceService.make_unicode(username)
         else:
-            transact_id = param.get('transact_id', '')
+            transact_no = param.get('transact_no', '')
 
-        item['transact_id'] = transact_id
-        if is_create and Transact.objects.filter(transact_id=transact_id).values().count():
-            return None, '新增时发现复重交易ID，请检查是否有重复记录: ' + transact_id
-        if not is_create and Transact.objects.filter(transact_id=transact_id).values().count() == 0:
-            return None, '修改信息的交易ID不存在: ' + transact_id
+        item['transact_no'] = transact_no
+        if is_create and Transact.objects.filter(transact_no=transact_no).values().count():
+            return None, '新增时发现复重交易ID，请检查是否有重复记录: ' + transact_no
+        if not is_create and Transact.objects.filter(transact_no=transact_no).values().count() == 0:
+            return None, '修改信息的交易ID不存在: ' + transact_no
         tz = pytz.timezone('Asia/Shanghai')
         # 返回datetime格式的时间
         now_time = timezone.now().astimezone(tz=tz).strftime("%Y-%m-%d %H:%M:%S")
@@ -240,7 +248,7 @@ class FinanceTransactService:
         # if transact_time else timezone.localtime() if is_create TODO USE_TZ = False 时会报错 如果USE_TZ设置为True时，Django会使用系统默认设置的时区，即America/Chicago，此时的TIME_ZONE不管有没有设置都不起作用。
         item['transact_time'] = datetime.strptime(transact_time, '%Y-%m-%d %H:%M:%S') \
             if transact_time else now if is_create \
-            else Transact.objects.filter(transact_id=transact_id).first().transact_time
+            else Transact.objects.filter(transact_no=transact_no).first().transact_time
         if not item['transact_time']:
             return None, '交易时间格式不正确'
 
@@ -291,24 +299,35 @@ class FinanceTransactService:
         enroll_id = param.get('enroll_id', '')
         if enroll_id:
             item['enroll_id'] = enroll_id
+
+        if param.get('finance_status_code', ''):
+            item['finance_status_code'] = param.get('finance_status_code', '')
+
         # 沙盒 ----------------------------------------------------------------------
         sand_box_name = param.get('sand_box', '')
-        if sand_box_name:
-            item['sand_box_set'] = SandBox.objects.filter(sand_box_name=sand_box_name).first()
+        if is_create:
+            if sand_box_name:
+                item['sand_box_set'] = SandBox.objects.filter(sand_box_name=sand_box_name).first()
+                if item['sand_box_set'] is None:
+                    return None, 'sand_box不存在'
+                item['sand_box'] = item['sand_box_set'].id
+        else:
+            item['sand_box_set'] = SandBox.objects.filter(id=res_data['sand_box']).first()
             if item['sand_box_set'] is None:
                 return None, 'sand_box不存在'
             item['sand_box'] = item['sand_box_set'].id
 
+        # SandBox.objects.filter(sand_box_name=sand_box_name).first()
         # 查余额 ---------------------------------------------------------------------
         balance_set = Transact.objects.filter(
             Q(account_id=account_id) &
             Q(currency_id=item['currency']) &
             Q(platform_id=item['platform_id']) &
             Q(transact_time__lt=item['transact_time']) &
-            ~Q(transact_id=item['transact_id'])
+            ~Q(transact_no=item['transact_no'])
         )
         # 如果有沙盒。
-        if sand_box_name:
+        if item['sand_box']:
             balance_set = balance_set.filter(Q(sand_box_id=item['sand_box']))
         else:
             balance_set = balance_set.filter(Q(sand_box_id=None))
@@ -322,7 +341,7 @@ class FinanceTransactService:
             item['balance'] = balance
 
         # 平台订单号是可以允许重复的，如果没有平台订单号则输入交易号
-        order_no = int(param.get('order_no', transact_id))  # 如果没有平台订单号则填交易号
+        order_no = int(param.get('order_no', transact_no))  # 如果没有平台订单号则填交易号
         item['order_no'] = order_no
 
         # 对方科目
@@ -362,9 +381,9 @@ class FinanceTransactService:
             # 单独判断，当有对方账号ID时才判断，因为在设计上对方账号是可以自动生成的
             if their_account_id:
                 repeat_order_set.filter(Q(their_account_id=their_account_id))
-            if repeat_order_set.count() > 0:
-                # return Response({'err': 1015, 'msg': '重复的交易订单号：' + str(order_no), })
-                return None, '重复的交易订单号：' + str(order_no)
+            # if repeat_order_set.count() > 0:
+            # return Response({'err': 1015, 'msg': '重复的交易订单号：' + str(order_no), })
+            # return None, '重复的交易订单号：' + str(order_no)
         # --------------------------------------------------------------------------------------
 
         if not param.get('their_account_id', '') and not param.get('their_account_name', ''):
@@ -423,6 +442,7 @@ class FinanceTransactService:
         serializer.validated_data['outgo'] = item['outgo']
         serializer.validated_data['balance'] = item['balance']
         serializer.validated_data['transact_time'] = item['transact_time']
+        serializer.validated_data['finance_status_code'] = item.get('finance_status_code', None)
 
         # print(">>> serializer.validated_data: ", serializer.validated_data,)
         # print(">>> serializer: ", serializer,)
@@ -445,7 +465,7 @@ class FinanceTransactService:
     def update(item):
         # print(">>> update:", item, )
 
-        transact = Transact.objects.filter(transact_id=item['transact_id']).first()
+        transact = Transact.objects.filter(transact_no=item['transact_no']).first()
         update_serializer = FinanceTransactSerializer(data=item, instance=transact)
         if not update_serializer.is_valid():
             # print(">>> serializer.errors:", serializer.errors, "\n")
